package com.develou.ratingbar_en_android

import android.os.Bundle
import android.view.Gravity.CENTER
import android.widget.LinearLayout
import android.widget.RatingBar
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import kotlin.random.Random

class MainActivity : AppCompatActivity() {
    private lateinit var ratingText: TextView
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        ratingText = findViewById(R.id.rating_text)

        createRatingBar()

        setupRatingBarWithChanges()
    }

    private fun createRatingBar() {
        val root: LinearLayout = findViewById(R.id.linear_layout)

        val ratingBar: RatingBar = RatingBar(this).apply {
            setIsIndicator(true)
            numStars = 5
            stepSize = 1.0f
            rating = randomBetweenOneAndFive()
            max = 5
            layoutParams = LinearLayout.LayoutParams(
                LinearLayout.LayoutParams.WRAP_CONTENT,
                LinearLayout.LayoutParams.WRAP_CONTENT
            ).apply { gravity = CENTER }
        }

        val ratingBarIndexInLayout = 3
        root.addView(ratingBar, ratingBarIndexInLayout)
    }

    private fun randomBetweenOneAndFive() = Random.nextInt(1, 5).toFloat()

    private fun setupRatingBarWithChanges() {
        val ratingBarChanges: RatingBar = findViewById(R.id.ratingbar_changes)

        setRatingText(numStars = ratingBarChanges.numStars)

        ratingBarChanges.setOnRatingBarChangeListener { ratingBar, rating, _ ->
            setRatingText(rating, ratingBar.numStars)
        }
    }

    private fun setRatingText(rating: Float = 0f, numStars: Int) {
        ratingText.text = formatRating(rating, numStars)
    }

    private fun formatRating(rating: Float, numStars: Int) = "$rating/${numStars}"
}